@@ -139,6 +139,7 @@
 #' library(timetk)
 #' library(parsnip)
 #' library(rsample)
+#' library(modeltime)
 #'
 #' # Data
 #' m750 <- m4_monthly %>% filter(id == "M750")
@@ -148,16 +149,16 @@
 #'
 #' # --- MODELS ---
 #'
-#' # Model 1: auto_arima ----
-#' model_fit_arima <- arima_reg() %>%
-#'     set_engine(engine = "auto_arima") %>%
+#' # Model 1: prophet ----
+#' model_fit_prophet <- prophet_reg() %>%
+#'     set_engine(engine = "prophet") %>%
 #'     fit(value ~ date, data = training(splits))
 #'
 #'
 #' # ---- MODELTIME TABLE ----
 #'
 #' models_tbl <- modeltime_table(
-#'     model_fit_arima
+#'     model_fit_prophet
 #' )
 #'
 #' # ---- CALIBRATE ----
@@ -772,7 +773,7 @@ mdl_time_forecast.workflow <- function(object, calibration_data, new_data = NULL
     # WORKFLOW MOLD
 
     # Contains $predictors, $outcomes, $blueprint
-    mld <- object %>% workflows::pull_workflow_mold()
+    mld <- object %>% workflows::extract_mold()
 
     # NEW DATA
 
@@ -928,7 +929,7 @@ mdl_time_forecast.workflow <- function(object, calibration_data, new_data = NULL
 
         nms_final <- names(data_formatted)
 
-        mld <- object %>% workflows::pull_workflow_mold()
+        mld <- object %>% workflows::extract_mold()
 
         actual_data_forged <- hardhat::forge(new_data = actual_data, blueprint = mld$blueprint, outcomes = TRUE)
 
